use strict;
use warnings;
use Parallel::Benchmark;
use Test::RedisServer;
use Redis::Fast;
use Log::Minimal;

my $redis_server = Test::RedisServer->new;
my $redis = Redis::Fast->new(
    $redis_server->connect_info
);

my @n = (
            1,
           10,
          100,
        1_000,
       10_000,
      100_000,
    1_000_000,
);

sub bench_lindex {
    my $count = shift;
    my $bm = Parallel::Benchmark->new(
        setup => sub {
            my ($self, $id) = @_;
            $redis->del("key:$id");
            $redis->lpush("key:$id", 1..$count);
        },
        benchmark => sub {
            my ($self, $id) = @_;
            $redis->lindex("key:$id", $count-1);
            return 1; # lindex
        },
        concurrency => 4,
    );

    $bm->run();
}
for my $count(@n) {
    infof 'lindex: %d', $count;
    bench_lindex $count;
}


sub bench_lpushpop {
    my $count = shift;
    my $bm = Parallel::Benchmark->new(
        setup => sub {
            my ($self, $id) = @_;
            $redis->del("key:$id");
            $redis->lpush("key:$id", 1..$count);
        },
        benchmark => sub {
            my ($self, $id) = @_;
            $redis->lpush("key:$id", 'a');
            $redis->lpop("key:$id");
            return 2; # lpush + lpop
        },
        concurrency => 4,
    );

    $bm->run();
}

for my $count(@n) {
    infof 'lpush & lpop: %d', $count;
    bench_lpushpop $count;
}
