use Test::RedisServer;
use Test::More;
use Time::HiRes qw( gettimeofday tv_interval );

# テスト用のRedisサーバを立ち上げる
my $redis_server = Test::RedisServer->new;

# Redisに接続する
use Redis::Fast;
my $redis = Redis::Fast->new(
    $redis_server->connect_info
);


# push @key, qw(a b c); に相当
push my @key, qw(a b c);
ok $redis->rpush(key => qw(a b c));

# pop @key; に相当
is pop @key, 'c';
is $redis->rpop('key'), 'c';

# $key[1]; に相当
is $key[1], 'b';
is $redis->lindex('key', 1), 'b';


my $pid = fork;
die "fork failed: $!" unless defined $pid;

if ($pid) {
    # 親プロセス
    my $start = [gettimeofday];

    my ($keyname, $job) = $redis->blpop("jobqueue", 30);
    is $keyname, "jobqueue";
    is $job, "awesome job";

    my $elapsed = tv_interval($start);
    cmp_ok $elapsed, '>=', 1;
    wait;
} else {
    # 子プロセス
    sleep 1;
    $redis->rpush("jobqueue", "awesome job");
    exit;
}

done_testing;
