use Test::RedisServer;
use Test::More;

# テスト用のRedisサーバを立ち上げる
my $redis_server = Test::RedisServer->new;

# Redisに接続する
use Redis::Fast;
my $redis = Redis::Fast->new(
    $redis_server->connect_info
);


subtest 'スクリプトの実行' => sub {
    my $lua = 'return redis.call("set",KEYS[1],ARGV[1])';
    is $redis->eval($lua, 1, 'key', 'value'), 'OK';
};

subtest 'スクリプトのキャッシュ' => sub {
    # スクリプトをキャッシュに保存
    my $lua = 'return redis.call("set",KEYS[1],ARGV[1])';
    my $sha = $redis->script_load($lua);

    # 保存したスクリプトを呼び出す
    is $redis->evalsha($sha, 1, 'key', 'value'), 'OK';
};

subtest 'Redis::Script' => sub {
    use Redis::Script;
    my $lua = 'return redis.call("set",KEYS[1],ARGV[1])';
    my $s = Redis::Script->new(script => $lua);
    is $s->eval($redis, ['key'], ['value']), 'OK';
};

done_testing;
